@@ -5,6 +5,19 @@ import os.path
 from os.path import dirname, abspath
 import array
 
+decodeUTF16b = UTF16Codec.decode
+try:
+    UTF16Codec.decode(array.array('H', [0x3042]))
+
+    def decodeUTF16a(a):
+        return UTF16Codec.decode(a)
+except:
+    # for codec does not support an array
+    print('fallback')
+
+    def decodeUTF16a(a):
+        return UTF16Codec.decode(a.tostring())
+
 
 class Morpheme:
     """
@@ -23,11 +36,9 @@ class Morpheme:
     def __str__(self):
         return self.fmt()
 
-    def fmt(self,
-            fmt="surface: {surface}, feature: {feature}, start={start}"):
-        return fmt.format(surface=self.surface,
-                          feature=self.feature,
-                          start=self.start)
+    def fmt(self, fmt="surface: {surface}, feature: {feature}, start={start}"):
+        return fmt.format(
+            surface=self.surface, feature=self.feature, start=self.start)
 
 
 class Tagger:
@@ -70,11 +81,12 @@ class Tagger:
         """
         if result is None:
             result = []
+        text = array.array('H', UTF16Codec.encode(text)[0])
         vn = self.__parse(text)
         wd = self.wdc.word_data
         while vn:
-            surface = text[vn.start:vn.start + vn.length]
-            feature = UTF16Codec.decode(wd(vn.word_id))[0]
+            surface = decodeUTF16a(text[vn.start:vn.start + vn.length])[0]
+            feature = decodeUTF16b(wd(vn.word_id))[0]
             result.append(Morpheme(surface, feature, vn.start))
             vn = vn.prev
         return result
@@ -86,17 +98,18 @@ class Tagger:
     @param result 分かち書き結果の文字列が追加されるリスト. None指定時は内部でリストを作成する
     @return 分かち書きされた文字列のリスト. {@code wakati(text,result)=result}
     """
+
     def wakati(self, text, result=None):
         if result is None:
             result = []
+        text = array.array('H', UTF16Codec.encode(text)[0])
         vn = self.__parse(text)
         while vn:
-            result.append(text[vn.start:vn.start + vn.length])
+            result.append(decodeUTF16a(text[vn.start:vn.start + vn.length])[0])
             vn = vn.prev
         return result
 
     def __parse(self, text):
-        text = array.array('H', UTF16Codec.encode(text)[0])
         length = len(text)
         nodes = [None] * (length + 1)
         nodes[0] = Tagger.__BOS_NODES
@@ -107,7 +120,7 @@ class Tagger:
         for i in range(0, length):
             if nodes[i] is not None:
                 fn.set(i)
-                wdc.search(text, i, fn)       # 単語辞書から形態素を検索
+                wdc.search(text, i, fn)  # 単語辞書から形態素を検索
                 unk.search(text, i, wdc, fn)  # 未知語辞書から形態素を検索
 
         cur = self.set_mincost_node(ViterbiNode.makeBOSEOS(),
