@@ -7,58 +7,48 @@ if sys.version_info[0] > 2:
     unichr = chr
 
 
-class Node:
+def base_id(nid):
     """
-    DoubleArrayのノード用の定数などが定義されているクラス
+    BASEノードに格納するID値をエンコードするためのメソッド
+    BASEノードに格納されているID値をデコードするためにも用いられる
     """
-    class Base:
-        """ BASEノード用の定数およびメソッドが定義されているクラス """
+    return (-nid) - 1
 
-        @staticmethod
-        def ID(nid):
-            """
-            BASEノードに格納するID値をエンコードするためのメソッド
-            BASEノードに格納されているID値をデコードするためにも用いられる
-            """
-            return (-nid) - 1
 
-    class Chck:
-        """
-        CHECKノード用の定数が定義されているクラス
-        """
-        TERMINATE_CODE = 0
-        """
-        文字列の終端を表す文字コード
+chck_TERMINATE_CODE = 0
+"""
+文字列の終端を表す文字コード
 
-        この文字はシステムにより予約されており、辞書内の形態素の表層形および解析対象テキストに含まれていた場合の動作は未定義
-        """
+この文字はシステムにより予約されており、辞書内の形態素の表層形および解析対象テキストに含まれていた場合の動作は未定義
+"""
 
-        VACANT_CODE = 1
-        """
-        CHECKノードが未使用だということを示すための文字コード
+chck_VACANT_CODE = 1
+"""
+CHECKノードが未使用だということを示すための文字コード
 
-        この文字はシステムにより予約されており、辞書内の形態素の表層形および解析対象テキストに含まれていた場合の動作は未定義
-        """
+この文字はシステムにより予約されており、辞書内の形態素の表層形および解析対象テキストに含まれていた場合の動作は未定義
+"""
 
-        CODE_LIMIT = 0xFFFF
-        """
-        使用可能な文字の最大値
-        """
+chck_CODE_LIMIT = 0xFFFF
+"""
+使用可能な文字の最大値
+"""
 
 
 class KeyStream:
     """
     文字列を文字のストリームとして扱うためのクラス。
-    readメソッドで個々の文字を順に読み込み、文字列の終端に達した場合には{@code Node.Chck.TERMINATE_CODE}が返される。
+    readメソッドで個々の文字を順に読み込み、文字列の終端に達した場合には{@code Chck_TERMINATE_CODE}が返される。
     * XXX: クラス名は不適切
     """
+    __slots__ = ['s', 'cur', 'len']
 
     def __init__(self, key, start=0):
         self.s = key
         self.cur = start
         self.len = len(key)
 
-    def startsWith(self, prefix):
+    def startswith(self, prefix):
         cur = self.cur
         s = self.s
         length = len(prefix)
@@ -72,7 +62,7 @@ class KeyStream:
 
     def read(self):
         if self.eos():
-            return Node.Chck.TERMINATE_CODE
+            return chck_TERMINATE_CODE
         else:
             p = self.cur
             self.cur += 1
@@ -86,6 +76,8 @@ class Searcher:
     """
     DoubleArray検索用のクラス
     """
+    __slots__ = ['rd', 'num_keys', 'begs', 'base', 'lens', 'chck', 'tail']
+
     def __init__(self, path, bigendian=False, use_mmap=None):
         """
         instantiate a DoubleArray Searcher
@@ -95,15 +87,15 @@ class Searcher:
         """
         self.rd = DictReader(path, bigendian, use_mmap)
         with self.rd as r:
-            nodeSz = r.getInt()
-            tindSz = r.getInt()
-            tailSz = r.getInt()
-            self.keySetSize = tindSz
-            self.begs = r.getIntArray(tindSz)
-            self.base = r.getIntArray(nodeSz)
-            self.lens = r.getShortArray(tindSz)
-            self.chck = r.getCharArray(nodeSz)
-            self.tail = r.getCharArray(tailSz)
+            node_size = r.get_int()
+            tind_size = r.get_int()
+            tail_size = r.get_int()
+            self.num_keys = tind_size
+            self.begs = r.get_intarray(tind_size)
+            self.base = r.get_intarray(node_size)
+            self.lens = r.get_shortarray(tind_size)
+            self.chck = r.get_chararray(node_size)
+            self.tail = r.get_chararray(tail_size)
 
     def release(self):
         del self.begs
@@ -119,7 +111,7 @@ class Searcher:
         DoubleArrayに格納されているキーの数を返す
         @return DoubleArrayに格納されているキー数
         """
-        return self.keySetSize
+        return self.num_keys
 
     def search(self, key):
         """
@@ -128,11 +120,19 @@ class Searcher:
         @param key 検索対象のキー文字列
         @return キーが見つかった場合はそのIDを、見つからなかった場合は-1を返す
         """
+        begs = self.begs
+        tail = self.tail
+        lens = self.lens
         base = self.base
         chck = self.chck
-        keyExists = self.keyExists
-
         node = base[0]
+
+        def exists(kin, node):
+            node_id = base_id(node)
+            beg = begs[node_id]
+            s = tail[beg:beg + lens[node_id]]
+            return kin.rest().equals(s)
+
         kin = KeyStream(key)
         code = kin.read()
         while 1:
@@ -141,12 +141,12 @@ class Searcher:
             if chck[idx] == code:
                 if node >= 0:
                     continue
-                elif kin.eos() or keyExists(kin, node):
-                    return Node.Base.ID(node)
+                elif kin.eos() or exists(kin, node):
+                    return base_id(node)
             return -1
 
 # with, iterator
-    def eachCommonPrefix(self, key, start, fn):
+    def commonprefix_search(self, key, start, fn):
         """
         common-prefix検索を行う
         条件に一致するキーが見つかる度に、fn.call(...)メソッドが呼び出される
@@ -157,17 +157,28 @@ class Searcher:
         """
         base = self.base
         chck = self.chck
+        begs = self.begs
+        tail = self.tail
+        lens = self.lens
         node = base[0]
         offset = -1
         kin = KeyStream(key, start)
 
+        def call_if_key_including(kin, node, start, offset, fn):
+            node_id = base_id(node)
+            l = lens[node_id]
+            beg = begs[node_id]
+            prefix = tail[beg:beg+l]
+            if kin.startswith(prefix):
+                fn(start, offset + l + 1, node_id)
+
         while 1:
             code = kin.read()
             offset += 1
-            terminalIdx = node + Node.Chck.TERMINATE_CODE
-            if chck[terminalIdx] == Node.Chck.TERMINATE_CODE:
-                fn(start, offset, Node.Base.ID(base[terminalIdx]))
-                if code == Node.Chck.TERMINATE_CODE:
+            terminal_idx = node + chck_TERMINATE_CODE
+            if chck[terminal_idx] == chck_TERMINATE_CODE:
+                fn(start, offset, base_id(base[terminal_idx]))
+                if code == chck_TERMINATE_CODE:
                     return
             idx = node + code
             node = base[idx]
@@ -175,19 +186,5 @@ class Searcher:
                 if node >= 0:
                     continue
                 else:
-                    self.call_if_keyIncluding(kin, node, start, offset, fn)
+                    call_if_key_including(kin, node, start, offset, fn)
             return
-
-    def call_if_keyIncluding(self, kin, node, start, offset, fn):
-        nodeId = Node.Base.ID(node)
-        l = self.lens[nodeId]
-        beg = self.begs[nodeId]
-        prefix = self.tail[beg:beg+l]
-        if kin.startsWith(prefix):
-            fn(start, offset + l + 1, nodeId)
-
-    def keyExists(self, kin, node):
-        nodeId = Node.Base.ID(node)
-        beg = self.begs[nodeId]
-        s = self.tail[beg:beg + self.lens[nodeId]]
-        return kin.rest().equals(s)
